@@ -4,7 +4,7 @@
 package config
 
 import (
-	"errors"
+	"fmt"
 	"net/url"
 	"os"
 	"path"
@@ -17,6 +17,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-shell/v14/client"
 	"gitlab.com/gitlab-org/gitlab-shell/v14/internal/gitaly"
 	"gitlab.com/gitlab-org/gitlab-shell/v14/internal/metrics"
+	"gitlab.com/gitlab-org/gitlab-shell/v14/internal/topology"
 )
 
 const (
@@ -98,6 +99,9 @@ type Config struct {
 	LFSConfig      LFSConfig          `yaml:"lfs"`
 	PATConfig      PATConfig          `yaml:"pat"`
 
+	// TopologyService contains Topology Service client configuration for Cells routing.
+	TopologyService topology.Config `yaml:"topology_service"`
+
 	httpClient     *client.HTTPClient
 	httpClientErr  error
 	httpClientOnce sync.Once
@@ -243,6 +247,10 @@ func newFromFile(path string) (*Config, error) {
 		cfg.LogFile = filepath.Join(cfg.RootDir, cfg.LogFile)
 	}
 
+	if err := cfg.TopologyService.Validate(); err != nil {
+		return nil, fmt.Errorf("invalid topology_service config: %w", err)
+	}
+
 	return cfg, nil
 }
 
@@ -268,17 +276,3 @@ func parseSecret(cfg *Config) error {
 
 	return nil
 }
-
-// IsSane checks if the given config fulfills the minimum requirements to be able to run.
-// Any error returned by this function should be a startup error. On the other hand
-// if this function returns nil, this doesn't guarantee the config will work, but it's
-// at least worth a try.
-func (c *Config) IsSane() error {
-	if c.GitlabURL == "" {
-		return errors.New("gitlab_url is required")
-	}
-	if c.Secret == "" {
-		return errors.New("secret or secret_file_path is required")
-	}
-	return nil
-}
